Request/Response structures for JSON-based communication
This module implements the standardized request-response model for all interactions with the Cognitive Nexus as defined in KIP specification section 6.
LLM Agents send structured requests (typically encapsulated in Function Calling) containing KIP commands to the Cognitive Nexus, which returns structured JSON responses.
Structs
- Error
Object - Structured error details for failed requests
- Request
- Defines the arguments for the
execute_kipfunction, which is the standard interface for an LLM to interact with the Cognitive Nexus.
Enums
- Command
Item - Represents a single command item in the batch
commandsarray. - Response
- Response structure from the Cognitive Nexus